==> component-select-3.7.23.tgz: package/es/Value.js <==
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import ReactSelect from 'react-select';
import { createComponent } from '@cloudflare/style-container';

const ValueComponent = (_ref) => {
  let className = _ref.className,
      props = _objectWithoutProperties(_ref, ["className"]);

  const key = props.id + '-key';
  return /*#__PURE__*/React.createElement("div", {
    className: className,
    key: key
  }, /*#__PURE__*/React.createElement(ReactSelect.defaultProps.valueComponent, props));
};

ValueComponent.propTypes = {
  className: PropTypes.string,
  children: PropTypes.node,
  disabled: PropTypes.bool,
  id: PropTypes.string,
  onClick: PropTypes.func,
  onRemove: PropTypes.func,
  value: PropTypes.object.isRequired
};
ValueComponent.displayName = 'Value';
const Value = createComponent(({
  theme,
  onRemove,
  disabled
}) => {
  // onRemove implies it's a multi-select value
  if (onRemove) return {
    backgroundColor: theme.colors.gray[9],
    border: `1px solid #a0a1a4`,
    color: theme.colors.gray[3],
    display: 'inline-block',
    fontSize: '.86667rem',
    marginLeft: '4px',
    marginTop: '4px',
    verticalAlign: 'top',
    '& .Select-value-icon': {
      cursor: disabled ? 'not-allowed' : 'pointer',
      padding: '3px 5px 1px 5px',
      display: 'inline-block',
      verticalAlign: 'middle',
      float: 'right'
    },
    '& .Select-value-icon:hover': {
      color: theme.colors.gray[3]
    },
    '& .Select-value-icon:focus': {
      backgroundColor: theme.colors.gray[7],
      color: theme.colors.gray[3]
    },
    '& .Select-value-icon:active': {
      backgroundColor: theme.colors.gray[7]
    },
    '& .Select-value-label': {
      cursor: 'default',
      padding: '2px 1px 2px 8px',
      position: 'relative',
      top: '2px'
    },
    '& .Select--multi a.Select-value-label': {
      color: theme.colors.blue[4],
      cursor: 'pointer',
      textDecoration: 'none'
    },
    '& .Select--multi a.Select-value-label:hover': {
      textDecoration: 'underline'
    }
  };
  return {
    bottom: 0,
    color: ' #333',
    left: 0,
    lineHeight: '32px',
    paddingLeft: '10px',
    paddingRight: '10px',
    position: 'absolute',
    right: 0,
    top: 0,
    maxWidth: '100%',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
  };
}, ValueComponent);
export default Value;

==> component-select-3.8.61.tgz: package/es/Value.js <==
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import ReactSelect from 'react-select';
import { createComponent } from '@cloudflare/style-container';

const ValueComponent = (_ref) => {
  let className = _ref.className,
      props = _objectWithoutProperties(_ref, ["className"]);

  const key = props.id + '-key';
  return /*#__PURE__*/React.createElement("div", {
    className: className,
    key: key
  }, /*#__PURE__*/React.createElement(ReactSelect.defaultProps.valueComponent, props));
};

ValueComponent.propTypes = {
  className: PropTypes.string,
  children: PropTypes.node,
  disabled: PropTypes.bool,
  id: PropTypes.string,
  onClick: PropTypes.func,
  onRemove: PropTypes.func,
  value: PropTypes.object.isRequired
};
ValueComponent.displayName = 'Value';
const Value = createComponent(({
  theme,
  onRemove,
  disabled
}) => {
  // onRemove implies it's a multi-select value
  if (onRemove) return {
    backgroundColor: theme.colors.gray[9],
    border: `1px solid ${theme.colors.gray[7]}`,
    color: theme.colors.gray[3],
    display: 'inline-block',
    fontSize: '.86667rem',
    marginLeft: '4px',
    marginTop: '4px',
    verticalAlign: 'top',
    '& .Select-value-icon': {
      cursor: disabled ? 'not-allowed' : 'pointer',
      padding: '3px 5px 1px 5px',
      display: 'inline-block',
      verticalAlign: 'middle',
      float: 'right'
    },
    '& .Select-value-icon:hover': {
      color: theme.colors.gray[3]
    },
    '& .Select-value-icon:focus': {
      backgroundColor: theme.colors.gray[7],
      color: theme.colors.gray[3]
    },
    '& .Select-value-icon:active': {
      backgroundColor: theme.colors.gray[7]
    },
    '& .Select-value-label': {
      cursor: 'default',
      padding: '2px 1px 2px 8px',
      position: 'relative',
      top: '2px'
    },
    '& .Select--multi a.Select-value-label': {
      color: theme.colors.blue[4],
      cursor: 'pointer',
      textDecoration: 'none'
    },
    '& .Select--multi a.Select-value-label:hover': {
      textDecoration: 'underline'
    }
  };
  return {
    bottom: 0,
    color: theme.colors.gray[1],
    left: 0,
    lineHeight: '32px',
    paddingLeft: '10px',
    paddingRight: '10px',
    position: 'absolute',
    right: 0,
    top: 0,
    maxWidth: '100%',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
  };
}, ValueComponent);
export default Value;
